#
# spec file for package kvm_stat
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kvm_stat
%define version %(rpm -q --qf '%%{VERSION}' kernel-source)
Version:        %{version}
Release:        lp151.7.3.1
Summary:        Monitoring Tool for KVM guests
License:        GPL-2.0-only
Group:          System/Monitoring
Url:            http://www.kernel.org/
BuildArch:      noarch
BuildRequires:  asciidoc
BuildRequires:  kernel-source >= 4.7.0
BuildRequires:  libxslt-tools

Requires:       python3-curses

Recommends:     kernel >= 4.7.0
Conflicts:      qemu < 2.6.90
Conflicts:      qemu-kvm < 2.6.90
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Patch0:         0001-tools-kvm_stat-fix-event-counts-display-for-interrup.patch
Patch1:         0002-tools-kvm_stat-fix-undue-use-of-initial-sleeptime.patch
Patch2:         0003-tools-kvm_stat-remove-unnecessary-header-redraws.patch
Patch3:         0004-tools-kvm_stat-simplify-line-print-logic.patch
Patch4:         0005-tools-kvm_stat-remove-extra-statement.patch
Patch5:         0006-tools-kvm_stat-simplify-initializers.patch
Patch6:         0007-tools-kvm_stat-move-functions-to-corresponding-class.patch
Patch7:         0008-tools-kvm_stat-show-cursor-in-selection-screens.patch
Patch8:         0009-tools-kvm_stat-display-message-indicating-lack-of-ev.patch
Patch9:         0010-tools-kvm_stat-make-heading-look-a-bit-more-like-top.patch
Patch10:        0011-tools-kvm_stat-rename-Current-column-to-CurAvg-s.patch
Patch11:        0012-tools-kvm_stat-add-new-interactive-command-h.patch
Patch12:        0013-tools-kvm_stat-add-new-interactive-command-s.patch
Patch13:        0014-tools-kvm_stat-add-new-interactive-command-o.patch
Patch14:        0015-tools-kvm_stat-display-guest-list-in-pid-guest-selec.patch
Patch15:        0016-tools-kvm_stat-fix-error-on-interactive-command-g.patch
Patch16:        0017-tools-kvm_stat-add-new-command-line-switch-i.patch
Patch17:        0018-tools-kvm_stat-add-new-interactive-command-b.patch
Patch18:        0019-tools-kvm_stat-add-f-help-to-get-the-available-event.patch
Patch19:        0020-tools-kvm_stat-Add-Python-3-support-to-kvm_stat.patch
Patch20:        0021-tools-kvm_stat-fix-command-line-option-g.patch
Patch21:        0022-tools-kvm_stat-fix-drilldown-in-events-by-guests-mod.patch
Patch22:        0023-tools-kvm_stat-fix-missing-field-update-after-filter.patch
Patch23:        0024-tools-kvm_stat-fix-extra-handling-of-help-with-field.patch
Patch24:        0025-tools-kvm_stat-add-hint-on-f-help-to-man-page.patch
Patch25:        0026-tools-kvm_stat-fix-child-trace-events-accounting.patch
Patch26:        0027-tools-kvm_stat-handle-invalid-regular-expressions.patch
Patch27:        0028-tools-kvm_stat-suppress-usage-information-on-command.patch
Patch28:        0029-tools-kvm_stat-stop-ignoring-unhandled-arguments.patch
Patch29:        0030-tools-kvm_stat-add-line-for-totals.patch
Patch30:        0031-tools-kvm_stat-sort-f-help-output.patch
Patch31:        0032-tools-kvm_stat-simplify-the-sortkey-function.patch
Patch32:        0033-tools-kvm_stat-use-a-namedtuple-for-storing-the-valu.patch
Patch33:        0034-tools-kvm_stat-use-a-more-pythonic-way-to-iterate-ov.patch
Patch34:        0035-tools-kvm_stat-avoid-is-for-equality-checks.patch
Patch35:        0036-tools-kvm_stat-fix-crash-when-filtering-out-all-non-.patch
Patch36:        0037-tools-kvm_stat-print-error-on-invalid-regex.patch
Patch37:        0038-tools-kvm_stat-fix-debugfs-handling.patch
Patch38:        0039-tools-kvm_stat-mark-private-methods-as-such.patch
Patch39:        0040-tools-kvm_stat-eliminate-extra-guest-pid-selection-d.patch
Patch40:        0041-tools-kvm_stat-separate-drilldown-and-fields-filteri.patch
Patch41:        0042-tools-kvm_stat-group-child-events-indented-after-par.patch
Patch42:        0043-tools-kvm_stat-print-Total-line-for-multiple-events-.patch
Patch43:        0044-tools-kvm_stat-Don-t-use-deprecated-file.patch
Patch44:        0045-tools-kvm_stat-fix-python3-issues.patch
Patch45:        0046-tools-kvm_stat-apply-python-2to3-fixes-to-kvm_stat.patch
Patch46:        0047-tools-kvm_stat-apply-python-2to3-fixes-to-kvm_stat2.patch
Patch47:        0048-tools-kvm_stat-apply-python-2to3-fixes-to-kvm_stat3.patch
Patch48:        0049-tools-kvm_stat-switch-python-reference-to-be-explici.patch

%description
This package provides a userspace tool "kvm_stat", which displays KVM vm exit
information as a means of monitoring vm behavior. The data is taken from the
KVM debugfs files or the vm tracepoints and outputs them as a curses ui or
simple text.

%prep
# copy necessary files from kernel-source
(tar -C /usr/src/linux -c COPYING tools scripts) | tar -x

%define SLE15_SP1_OR_LEAP15_1 0%{?sle_version} == 150100
%define FACTORY     0%{?is_opensuse} && 0%{?suse_version} > 1500
%define SLE_LEAP_15 0%{?sle_version} <= 150000 && 0%{?suse_version} <= 1500

# Apply the first patches to SLES15-SP1 and Leap 15.1
%if 0%{?SLE15_SP1_OR_LEAP15_1}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
%endif

# If the build is SLE15 / Leap 15 or older
%if 0%{?SLE_LEAP_15}
%patch46 -p1
%endif

# If the build is Factory or Tumbleweed only
%if 0%{?FACTORY}
%patch47 -p1
%endif

%patch48 -p1

%build
make -C tools/kvm/kvm_stat %{?_smp_mflags}

%install
make -C tools kvm_stat_install INSTALL_ROOT=%{buildroot}

%files
%defattr(-, root, root)
%license COPYING
%{_bindir}/kvm_stat
%{_mandir}/man1/kvm_stat*

%changelog
* Wed Aug 14 2019 Bruce Rogers <brogers@suse.com>
- Fix our patching for Leap 15.1 (boo#1140899)
* Thu Nov 29 2018 Larry Dewey <ldewey@suse.com>
  * Changed the spec file to build SLE15-SP1 with the s390x patches,
  and added logic to the spec file to uniquely build Factory and
  SLE-15 as they do not require the first 44 patches, and the code
  base is not the same
- Making kvm_stat use python3 for openSUSE (bsc#1116822)
  - 0047-tools-kvm_stat-switch-python-reference-to-be-explici.patch
  + 0047-tools-kvm_stat-apply-python-2to3-fixes-to-kvm_stat2.patch
  + 0048-tools-kvm_stat-apply-python-2to3-fixes-to-kvm_stat3.patch
  + 0049-tools-kvm_stat-switch-python-reference-to-be-explici.patch
* Mon Nov 26 2018 Bruce Rogers <brogers@suse.com>
- Make kvm_stat use python3 (bsc#1116822)
  + 0044-tools-kvm_stat-Don-t-use-deprecated-file.patch
  + 0045-tools-kvm_stat-fix-python3-issues.patch
  + 0046-tools-kvm_stat-apply-python-2to3-fixes-to-kvm_stat.patch
  + 0047-tools-kvm_stat-switch-python-reference-to-be-explici.patch
* Mon Nov 19 2018 Larry Dewey <ldewey@suse.com>
  * Incorporating patches and comments produced by Fei Li for
  SLE15-SP1
- Backport 43 kvm_stat patches between kernel v4.16-* and current
  v4.12.14 for the kvm_stat package. Actually some of the patches
  are s390x specific, and some are noarch. (FATE#325017)
  + 0001-tools-kvm_stat-fix-event-counts-display-for-interrup.patch
  + 0002-tools-kvm_stat-fix-undue-use-of-initial-sleeptime.patch
  + 0003-tools-kvm_stat-remove-unnecessary-header-redraws.patch
  + 0004-tools-kvm_stat-simplify-line-print-logic.patch
  + 0005-tools-kvm_stat-remove-extra-statement.patch
  + 0006-tools-kvm_stat-simplify-initializers.patch
  + 0007-tools-kvm_stat-move-functions-to-corresponding-class.patch
  + 0008-tools-kvm_stat-show-cursor-in-selection-screens.patch
  + 0009-tools-kvm_stat-display-message-indicating-lack-of-ev.patch
  + 0010-tools-kvm_stat-make-heading-look-a-bit-more-like-top.patch
  + 0011-tools-kvm_stat-rename-Current-column-to-CurAvg-s.patch
  + 0012-tools-kvm_stat-add-new-interactive-command-h.patch
  + 0013-tools-kvm_stat-add-new-interactive-command-s.patch
  + 0014-tools-kvm_stat-add-new-interactive-command-o.patch
  + 0015-tools-kvm_stat-display-guest-list-in-pid-guest-selec.patch
  + 0016-tools-kvm_stat-fix-error-on-interactive-command-g.patch
  + 0017-tools-kvm_stat-add-new-command-line-switch-i.patch
  + 0018-tools-kvm_stat-add-new-interactive-command-b.patch
  + 0019-tools-kvm_stat-add-f-help-to-get-the-available-event.patch
  + 0020-tools-kvm_stat-Add-Python-3-support-to-kvm_stat.patch
  + 0021-tools-kvm_stat-fix-command-line-option-g.patch
  + 0022-tools-kvm_stat-fix-drilldown-in-events-by-guests-mod.patch
  + 0023-tools-kvm_stat-fix-missing-field-update-after-filter.patch
  + 0024-tools-kvm_stat-fix-extra-handling-of-help-with-field.patch
  + 0025-tools-kvm_stat-add-hint-on-f-help-to-man-page.patch
  + 0026-tools-kvm_stat-fix-child-trace-events-accounting.patch
  + 0027-tools-kvm_stat-handle-invalid-regular-expressions.patch
  + 0028-tools-kvm_stat-suppress-usage-information-on-command.patch
  + 0029-tools-kvm_stat-stop-ignoring-unhandled-arguments.patch
  + 0030-tools-kvm_stat-add-line-for-totals.patch
  + 0031-tools-kvm_stat-sort-f-help-output.patch
  + 0032-tools-kvm_stat-simplify-the-sortkey-function.patch
  + 0033-tools-kvm_stat-use-a-namedtuple-for-storing-the-valu.patch
  + 0034-tools-kvm_stat-use-a-more-pythonic-way-to-iterate-ov.patch
  + 0035-tools-kvm_stat-avoid-is-for-equality-checks.patch
  + 0036-tools-kvm_stat-fix-crash-when-filtering-out-all-non-.patch
  + 0037-tools-kvm_stat-print-error-on-invalid-regex.patch
  + 0038-tools-kvm_stat-fix-debugfs-handling.patch
  + 0039-tools-kvm_stat-mark-private-methods-as-such.patch
  + 0040-tools-kvm_stat-eliminate-extra-guest-pid-selection-d.patch
  + 0041-tools-kvm_stat-separate-drilldown-and-fields-filteri.patch
  + 0042-tools-kvm_stat-group-child-events-indented-after-par.patch
  + 0043-tools-kvm_stat-print-Total-line-for-multiple-events-.patch
* Fri Nov  9 2018 Bruce Rogers <brogers@suse.com>
- Add "Requires: python-curses" in kvm_stat.spec as this package
  needs to be installed to make kvm_stat work. (bsc#1114465)
* Thu Jul 26 2018 brogers@suse.com
- Add a qemu package conflicts directive since SLE releases provided
  the kvm_stat script via the qemu package, while older openSUSE
  releases had provided it through qemu-kvm, which is already
  handled. (bsc#1102746 related)
- Change package to be noarch. kvm_stat is written in python, and
  is useful to multiple architectures which have kvm support.
- Drop the kernel README and CREDITS files, since they don't really
  represent this package in any meaningful way.
- Minor spec file tweaks performed.
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Sun Oct 30 2016 jengelh@inai.de
- Simplify copying around
* Mon Oct 17 2016 brogers@suse.com
- soften runtime Requires kernel version to a Recommends since it
  really doesn't fully enforce anything which is "required".
* Mon Oct 17 2016 brogers@suse.com
- fix conflicts line to be against qemu-kvm, not qemu.
* Wed Jun 22 2016 brogers@suse.com
- initial check-in of kvm_stat package. Previously the kvm_stat
  tool was included with the qemu sources, but because kvm_stat simply
  represents kvm module information, as of v4.7.0 of the linux kernel,
  kvm_stat was included in the tools directory under the linux source,
  hence this package was born.
